( cd usr/share/doc/gnome-keyring-manager-2.12.0 ; rm -rf build )
( cd usr/share/doc/gnome-keyring-manager-2.12.0 ; ln -sf /usr/src/garnome-Ptgz-kit build )
#%% begin initialize gnome_keyring_manager-2.12.0-i386-P1
if [ -x /usr/bin/scrollkeeper-update ]; then
  /usr/bin/scrollkeeper-update -q || exit 1
fi
GCONFTOOL=/usr/bin/gconftool-2
if [ ! -x $GCONFTOOL ]; then
  exit 1
fi
GCONF_CONFIG_SOURCE=`$GCONFTOOL --get-default-source`
export GCONF_CONFIG_SOURCE
GCONF_DIR=/usr/etc/gconf
SCHEMA_DIR=$GCONF_DIR/schemas
SCHEMA_FILES=" \
  gnome-keyring-manager.schemas \
  "
for s in $SCHEMA_FILES; do
  $GCONFTOOL --makefile-install-rule $SCHEMA_DIR/$s > /dev/null
done
#%% end
